<?php
/*
Plugin Name: MAGNETIS Call-tracking
Plugin URI: https://www.magnetis.fr/extension-wordpress-call-tracking
Description: Analysez l'origine de vos appels entrants avec le Call-tracking Magnétis. Déterminez quels canaux vous génèrent le plus d’appels et optimisez votre budget de communication. L'extension de Call-Tracking Magnétis intègre vos numéros trackés directement dans votre site Wordpress et vous donne accès à un dashboard directement dans votre administration.
Version: 4.0
Author: Magnetis
Author URI: https://www.magnetis.fr/equipe-magnetis
License: GPL2
*/

if (get_option('magnetis_apikey')!="") {
  add_action('wp_enqueue_scripts', array('magnetis_number','magnetis_script_inpage')); 
}
wp_enqueue_script('jquery-ui-datepicker');
wp_enqueue_style('jquery-ui-css', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.2/themes/smoothness/jquery-ui.css');


class magnetis_number{	
	function magnetis_script_inpage()
	{
		$response = @file_get_contents('https://app.magnetis.fr/console/connector/wordpressboard/metrics/'.get_option('magnetis_apikey').'/'.get_option('custom_period'));
        
        if($response)
        {
            $decoded = json_decode($response);
            if($decoded->status == 'ok')
            	update_option('magnetis_dataToken',$decoded->scriptToken);
        }
        
        if(get_option('magnetis_dataToken')!='')
        {
        	if(get_option('type_module')=="standard_settings")
        	    wp_register_script('magnetis_script', '//call.mgtmod01.com/mgtct.v5.min.js?Apk='.get_option('magnetis_dataToken').'&t=w', array(), null, true);
            if(get_option('type_module')=="dedicated_settings")
            	wp_register_script('magnetis_script', '//call.mgtmod01.com/mgtct.aw.min.js?Apk='.get_option('magnetis_dataToken').'&t=w', array(), null, true);

            wp_enqueue_script('magnetis_script');
        }
	}
	
}

add_action('admin_init', array('magnetis_backoffice','magnetis_admin_init'));
add_action('all_admin_notices',array('magnetis_backoffice','top_message'));
add_action('admin_menu', array('magnetis_backoffice','magnetis_admin_menu'));

class magnetis_backoffice{
	function magnetis_admin_init()
	{
		register_setting( 'settings-group', 'magnetis_apikey' );
		register_setting( 'settings-group', 'magnetis_dataToken' );
		register_setting( 'settings-group', 'custom_period' );
		register_setting( 'settings-group', 'type_module' );
	}
	
	function top_message()
	{
		if(get_option('magnetis_apikey')==""){
			echo "<div class=\"update-nag\">";
			echo "<p><b>Call-tracking Magnétis</b> : <a href=\"".@admin_url('options-general.php?page=magnetis_parameters_page')."\">ajoutez votre clé API</a> pour activer votre module de call-tracking.</p>";
			echo "</div>";
		}
	}
	
	function magnetis_admin_menu()
	{
	  add_options_page('Magnétis Call Tracking', 'Magnétis', 'manage_options', 'magnetis_parameters_page', array('magnetis_backoffice','magnetis_page'));
	}
	
	function magnetis_page()
	{
	  if(!current_user_can('manage_options')) {
	    wp_die(__('You do not have sufficient permissions to access this page.'));
	  }?>
	        <h3>Paramètres du call-tracking Magnétis</h3>
	        <table>
	        <form action="options.php" method="POST">
		        <?php @settings_fields('settings-group'); ?>
				<?php @do_settings_fields('', 'settings-group'); ?>
		        <?php 
		            if(isset($_POST['magnetis_apikey'])) update_option('magnetis_apikey',$_POST['magnetis_apikey']);
		            if(isset($_POST['custom_period'])) update_option('custom_period',$_POST['custom_period']);
		            if(isset($_POST['type_module'])) update_option('type_module',$_POST['type_module']);
		        ?>

				<tr>
					<th scope="row" style="text-align:left"><label for="magnetis_apikey"><b>Clé API Magnétis</b></label></th>
					<td><input type="text" name="magnetis_apikey" id="magnetis_apikey" style="width: 363px;" value="<?php echo get_option('magnetis_apikey'); ?>" placeholder="A8hfg630KhB0uiEG6r" /></td>
				</tr>
				<tr>
					<td scope="row"><b>Période par défaut</b></td>
					<td>
						<select name="custom_period">
							<option value="1" <?php if(get_option('custom_period')=="1") echo "selected"; ?>>1 jour</option>
							<option value="7" <?php if(get_option('custom_period')=="7") echo "selected"; ?>>7 jours</option>
							<option value="30" <?php if(get_option('custom_period')=="30") echo "selected"; ?>>30 jours</option>
							<option value="45" <?php if(get_option('custom_period')=="45") echo "selected"; ?>>45 jours</option>
							<option value="90" <?php if(get_option('custom_period')=="90") echo "selected"; ?>>90 jours</option>
						</select>
					</td>
				</tr>
				<tr>
					<th scope="row" style="text-align:left"><label for="type_module"><b>Type de module</b></label></th>
					<td>
						<select name="type_module" id="type_module">
							<option <?php if(get_option('type_module')=="standard_settings") echo "selected"; ?> value="standard_settings" >Configuration standard par support de communication [Par défaut]</option>
							<option <?php if(get_option('type_module')=="dedicated_settings") echo "selected"; ?> value="dedicated_settings">Configuration de gestion des mots clés Adwords</option>
						</select>
					</td>
				</tr>
				<tr>
					<td colspan="2">
	                    <?php submit_button('Enregistrer les paramètres'); ?>
					</td>
				</tr>
	        </form>
	        </table>
	        <p>Vous pouvez retrouver votre clé API directement dans <a href="https://www.magnetis.fr/console/" target="_blank">votre compte Magnétis</a>. Si vous n'avez pas encore de compte Magnétis, vous pouvez en <a href="https://www.magnetis.fr/console/subscription" target="_blank">créer un gratuitement en cliquant ici.</a> Dans votre interface Magnétis, vous devez utiliser la clé dédié au compte concerné par le module et non la clé intitulée "Tous les comptes"</p>
	        <p>Une fois votre clé API saisie dans Wordpress, le script de suivi du call-tracking sera automatiquement installé sur toutes les pages de votre site si vous avez activé le module dans l'interface Magnétis. Vous retrouverez également vos statistiques dans votre tableau de bord Wordpress.</a></p>
	        <p>Notre <a href="https://www.magnetis.fr/console/" target="_blank">équipe support</a> se tient à votre disposition pour vous conseiller dans la configuration de votre module et de votre architecture de call-tracking.</p>
	        <script type="text/javascript">
			jQuery(document).ready(function($) {
				$('.custom_date').datepicker({
					dateFormat : 'dd-mm-yy'
				});
			});
			</script>
	  <?php
	}
}

add_action('wp_dashboard_setup',array('magnetis_widget','magnetis_dashboard_widget'));

class magnetis_widget
{
	function magnetis_dashboard_widget()
	{
		global $wp_meta_boxes;
		
		$period = get_option('custom_period');
		$dates = '';
		if(!empty($period) AND !is_null($period)){
			$enddate = date("d/m/Y");
			$startdate = date("d/m/Y", strtotime(" -$period days"));
			$dates = " - Du ". $startdate." au ".$enddate;
		}

		wp_add_dashboard_widget('magnetis_metrics_widget','Statistiques du call-tracking Magnétis'.$dates,array('magnetis_widget','magnetis_dashboard_widget_content'));
	}
	
	function magnetis_dashboard_widget_content()
	{
		$metrics_get = @file_get_contents('https://app.magnetis.fr/console/connector/wordpressboard/metrics/'.get_option('magnetis_apikey').'/'.get_option('custom_period'));
		?>
        <style>
			.magnetis_widget_metricspace{
				width:33%;
				float:left;
				text-align:center;
			}
			.magnetis_widget_metrictitle{
				font-size: 0.9em;
			}
			.magnetis_widget_metricvalue{
				font-size: 22px;
				font-weight: bold;
				padding: 8px 0px 8px 0px;
			}
			.magnetis_widget_table{
				border-spacing: 0;
				border-collapse: collapse !important;
				width: 100%;
				max-width: 100%;
				margin-bottom: 20px;
			}
			.magnetis_widget_table caption{
				padding-top: 8px;
				padding-bottom: 8px;
				color: #777;
				text-align: center;
				font-size: 16px;
			}
			.magnetis_widget_table th{
				padding: 0;
				border: 1px solid #ddd;
				padding: 8px;
				line-height: 1.42857143;
				vertical-align: top;
				border-top: 2px solid #009cf1;
			}
			.magnetis_widget_table td{
				padding: 0;
				border: 1px solid #ddd;
				padding: 8px;
				line-height: 1.42857143;
				vertical-align: top;
				border-top: 1px solid #ddd;
				text-align:center;
			}
			.magnetis_widget_table td:first-child{
				text-align:left;
			}
			
			.magnetis_widget_table > tbody > tr:nth-child(odd) {
				background-color: #eaeff2;
			}
		</style>


		<?php
		if($metrics_get)
		{
			$magnetis_widget_metrics = json_decode($metrics_get);?>

		
		<?php if(isset($magnetis_widget_metrics->dataMetrics)){?>
			<div class="magnetis_widget_metricspace">
				<div class="magnetis_widget_metrictitle">Nombre d'appels</div>
				<div class="magnetis_widget_metricvalue"><?php echo $magnetis_widget_metrics->dataMetrics->calls;?></div>
			</div>
			<div class="magnetis_widget_metricspace">
				<div class="magnetis_widget_metrictitle">Temps d'appels</div>
				<div class="magnetis_widget_metricvalue"><?php echo $magnetis_widget_metrics->dataMetrics->duration;?></div>
			</div>
			<div class="magnetis_widget_metricspace">
				<div class="magnetis_widget_metrictitle">Appels manqués</div>
				<div class="magnetis_widget_metricvalue"><?php echo $magnetis_widget_metrics->dataMetrics->lost;?> - [<?php echo $magnetis_widget_metrics->dataMetrics->lost_part;?>%]</div>
			</div>
			<div style="clear: both"></div>
			<hr>
		<?php }?>
		<?php if(isset($magnetis_widget_metrics->channelMetrics)){?>
			<table class="magnetis_widget_table">
				<caption>Origines des appels</caption>
				<thead>
					<tr>
						<th>Source</th>
						<th>Nb</th>
						<th>%</th>
					</tr>
				</thead>
				<tbody>
					<?php if((is_array($magnetis_widget_metrics->channelMetrics) OR is_object($magnetis_widget_metrics->channelMetrics)) AND count((array)$magnetis_widget_metrics->channelMetrics)>0){
						foreach($magnetis_widget_metrics->channelMetrics as $channelClassement=>$channelData){?>
						<tr>
							<td><?php echo $channelData->name;?></td>
							<td><?php echo $channelData->calls;?></td>
							<td><?php echo $channelData->calls_part;?>%</td>
						</tr>
						<?php }?>
					<?php }else{?>
					<tr>
						<td colspan="3"><center>Aucunes données disponibles.</center></td>
					</tr>
					<?php }?>
				</tbody>
			</table>
			<p><a href="<?php echo @admin_url('options-general.php?page=magnetis_parameters_page');?>">Paramètres</a> du module de call-tracking</p>
			<?php }?>
		<?php }else{ ?>

             <div class="magnetis_widget_metricspace">
				<div class="magnetis_widget_metrictitle">Nombre d'appels</div>
				<div class="magnetis_widget_metricvalue">0</div>
			</div>
			<div class="magnetis_widget_metricspace">
				<div class="magnetis_widget_metrictitle">Temps d'appels</div>
				<div class="magnetis_widget_metricvalue">0</div>
			</div>
			<div class="magnetis_widget_metricspace">
				<div class="magnetis_widget_metrictitle">Appels manqués</div>
				<div class="magnetis_widget_metricvalue">0 - [0%]</div>
			</div>
			<div style="clear: both"></div>
			<hr>
            <table class="magnetis_widget_table">
				<caption>Origines des appels</caption>
				<thead>
					<tr>
						<th>Source</th>
						<th>Nb</th>
						<th>%</th>
					</tr>
				</thead>
				<tbody>
				    <?php if(get_option('magnetis_apikey')!=""){ ?>
					<tr>
						<td colspan="3"><center><?php echo "<p>Données non accessibles à cause d'un <b>problème d'identification</b>.<br>Merci de vérifier <a href=\"".@admin_url('options-general.php?page=magnetis_parameters_page')."\">les paramètres</a>.</p>"; ?></center></td>
					</tr>
					<?php } else {  ?>
                    <tr>
						<td colspan="3"><center><?php echo '<p>Les statistiques ne sont pas accessibles.</p>'; ?></center></td>
					</tr>
					<?php } ?>
				</tbody>
			</table>
			<p><a href="<?php echo @admin_url('options-general.php?page=magnetis_parameters_page');?>">Paramètres</a> du module de call-tracking</p>


		<?php
		}?>
	<?php
	}
}
